@@ -21,6 +21,7 @@
 #include "rtcom-eventlogger/eventlogger.h"
 #include "rtcom-eventlogger/eventlogger-plugin.h"
 #include "rtcom-eventlogger/event.h"
+#include "rtcom-eventlogger/db.h"
 
 #include <glib.h>
 #include <sqlite3.h>
@@ -78,11 +79,6 @@ enum
     RTCOM_EL_ITER_PROP_ATOMIC,
 };
 
-extern gboolean
-rtcom_el_db_commit_transaction (RTComEl *el);
-extern gint
-rtcom_el_db_busy_loop (sqlite3_stmt *stmt);
-
 void _update_representation(
         RTComElIterPrivate * priv)
 {
@@ -92,9 +88,9 @@ void _update_representation(
     g_return_if_fail(priv->rep);
 
     if (priv->columns)
-        rtcom_el_query_update_row (priv->stmt, priv->columns);
+        rtcom_el_db_schema_update_row (priv->stmt, priv->columns);
     else
-        priv->columns = rtcom_el_query_get_row (priv->stmt);
+        priv->columns = rtcom_el_db_schema_get_row (priv->stmt);
 
 #define LOOKUP_INT(x) (g_value_get_int (g_hash_table_lookup (priv->columns, x)))
 #define LOOKUP_STR(x) (g_value_dup_string (g_hash_table_lookup (priv->columns, x)))
@@ -286,7 +282,7 @@ static void rtcom_el_iter_finalize(
     RTComElIterPrivate * priv = RTCOM_EL_ITER_GET_PRIV(object);
 
     if (priv->atomic)
-      rtcom_el_db_commit_transaction (priv->el);
+      rtcom_el_db_commit (priv->db, NULL);
 
     g_object_unref(priv->el);
     g_object_unref(priv->query);
@@ -417,7 +413,7 @@ gboolean rtcom_el_iter_next(
     g_return_val_if_fail(priv->db, FALSE);
     g_return_val_if_fail(priv->stmt, FALSE);
 
-    status = rtcom_el_db_busy_loop (priv->stmt);
+    status = rtcom_el_db_iterate (priv->db, priv->stmt, NULL);
     if(status == SQLITE_DONE)
     {
         sqlite3_finalize(priv->stmt);
@@ -469,7 +465,7 @@ gboolean rtcom_el_iter_refresh(
     }
     else
     {
-        status = rtcom_el_db_busy_loop (priv->stmt);
+        status = rtcom_el_db_iterate (priv->db, priv->stmt, NULL);
         if(status == SQLITE_DONE)
         {
             sqlite3_finalize(priv->stmt);
@@ -561,7 +557,7 @@ RTComElAttachIter * rtcom_el_iter_get_attachments(
         goto ret_null;
     }
 
-    status = rtcom_el_db_busy_loop (stmt);
+    status = rtcom_el_db_iterate (priv->db, stmt, NULL);
     if (status == SQLITE_DONE)
     {
         g_debug ("no attachments found");
